@@ -51,10 +51,10 @@
 
     snapshotted_data as (
 
-        select {{ target_relation.quote(schema=False, identifier=False) }}.*,
+        select {{ target_relation }}.*,
             {{ strategy.unique_key }} as dbt_unique_key
 
-        from {{ target_relation.quote(schema=False, identifier=False) }}
+        from {{ target_relation }}
         where dbt_valid_to is null
 
     ),
@@ -141,7 +141,7 @@
             snapshotted_data.dbt_scd_id
 
         from snapshotted_data
-        left join deletes_source_data as source_data on snapshotted_data.dbt_unique_key = source_data.dbt_unique_key
+        left join deletes_source_data source_data on snapshotted_data.dbt_unique_key = source_data.dbt_unique_key
         where source_data.dbt_unique_key is null
     )
     {%- endif %}
